import { Globals } from '@react-spring/core';
export * from '@react-spring/core';
import { createHost } from '@react-spring/animated';
import { createStringInterpolator } from '@react-spring/shared/stringInterpolation';
import { applyInitialPropsToInstance } from 'react-babylonjs/dist/UpdateInstance';
import { intrinsicClassMap, CustomPropsHandler, PropChangeType } from 'react-babylonjs';
import { Color3, Color4, Vector3 } from '@babylonjs/core';

var elements = Object.keys(intrinsicClassMap);
var primitives = ['primitive'].concat(elements);

function parseRgbaString(rgba) {
    var arr = rgba.replace(/[^\d,]/g, '').split(',');
    return arr.map(function (num) { return parseInt(num, 10) / 255; });
}
var Key = 'react-babylon-spring';
var CustomColor3StringHandler = /** @class */ (function () {
    function CustomColor3StringHandler() {
        this.propChangeType = PropChangeType.Color3;
    }
    Object.defineProperty(CustomColor3StringHandler.prototype, "name", {
        get: function () {
            return Key + ":Color3String";
        },
        enumerable: false,
        configurable: true
    });
    CustomColor3StringHandler.prototype.accept = function (newProp) {
        return typeof (newProp) === 'string';
    };
    CustomColor3StringHandler.prototype.process = function (oldProp, newProp) {
        if (oldProp !== newProp) {
            return {
                processed: true,
                value: Color3.FromArray(parseRgbaString(newProp))
            };
        }
        return { processed: false, value: null };
    };
    return CustomColor3StringHandler;
}());
var CustomColor3ArrayHandler = /** @class */ (function () {
    function CustomColor3ArrayHandler() {
        this.propChangeType = PropChangeType.Color3;
    }
    Object.defineProperty(CustomColor3ArrayHandler.prototype, "name", {
        get: function () {
            return Key + ":Color3Array";
        },
        enumerable: false,
        configurable: true
    });
    CustomColor3ArrayHandler.prototype.accept = function (newProp) {
        return Array.isArray(newProp);
    };
    CustomColor3ArrayHandler.prototype.process = function (oldProp, newProp) {
        if (oldProp === undefined || oldProp.length !== newProp.length) {
            // console.log(`found diff length (${oldProp?.length}/${newProp?.length}) Color3Array new? ${oldProp === undefined}`)
            return {
                processed: true,
                value: Color3.FromArray(newProp)
            };
        }
        for (var i = 0; i < oldProp.length; i++) {
            if (oldProp[i] !== newProp[i]) {
                // console.log('found diff value Color3Array')
                return {
                    processed: true,
                    value: Color3.FromArray(newProp)
                };
            }
        }
        return { processed: false, value: null };
    };
    return CustomColor3ArrayHandler;
}());
var CustomColor4StringHandler = /** @class */ (function () {
    function CustomColor4StringHandler() {
        this.propChangeType = PropChangeType.Color4;
    }
    Object.defineProperty(CustomColor4StringHandler.prototype, "name", {
        get: function () {
            return Key + ":Color4String";
        },
        enumerable: false,
        configurable: true
    });
    CustomColor4StringHandler.prototype.accept = function (newProp) {
        return typeof (newProp) === 'string';
    };
    CustomColor4StringHandler.prototype.process = function (oldProp, newProp) {
        if (oldProp !== newProp) {
            // console.log('found diff Color4String')
            return {
                processed: true,
                value: Color4.FromArray(parseRgbaString(newProp))
            };
        }
        return { processed: false, value: null };
    };
    return CustomColor4StringHandler;
}());
var CustomVector3ArrayHandler = /** @class */ (function () {
    function CustomVector3ArrayHandler() {
        this.propChangeType = PropChangeType.Vector3;
    }
    Object.defineProperty(CustomVector3ArrayHandler.prototype, "name", {
        get: function () {
            return Key + ":Vector3Array";
        },
        enumerable: false,
        configurable: true
    });
    CustomVector3ArrayHandler.prototype.accept = function (newProp) {
        return Array.isArray(newProp);
    };
    CustomVector3ArrayHandler.prototype.process = function (oldProp, newProp) {
        if (oldProp === undefined || oldProp.length !== newProp.length) {
            // console.log(`found diff length (${oldProp?.length}/${newProp?.length}) Color3Array new? ${oldProp === undefined}`)
            return {
                processed: true,
                value: Vector3.FromArray(newProp)
            };
        }
        for (var i = 0; i < oldProp.length; i++) {
            if (oldProp[i] !== newProp[i]) {
                return {
                    processed: true,
                    value: Vector3.FromArray(newProp)
                };
            }
        }
        return { processed: false, value: null };
    };
    return CustomVector3ArrayHandler;
}());
CustomPropsHandler.RegisterPropsHandler(new CustomColor3StringHandler());
CustomPropsHandler.RegisterPropsHandler(new CustomColor3ArrayHandler());
CustomPropsHandler.RegisterPropsHandler(new CustomColor4StringHandler());
CustomPropsHandler.RegisterPropsHandler(new CustomVector3ArrayHandler());

// todo: frameLoop can use runRenderLoop
Globals.assign({
    createStringInterpolator: createStringInterpolator,
});
var host = createHost(primitives, {
    applyAnimatedValues: applyInitialPropsToInstance,
});
var animated = host.animated;

export { animated };
//# sourceMappingURL=react-babylon-spring.js.map
